OsStrParser

Struct OsStrParser 

pub struct OsStrParser<T> { /* private fields */ }
Available on crate feature clap-parse only.
A clap parser that converts &OsStr to an Input or Output

Implementations

Source

impl<T> OsStrParser<T>

pub fn exists(self) -> Self

This path must exist

pub fn is_dir(self) -> Self

If this path exists it must point to a directory

pub fn is_file(self) -> Self

If this path exists it must point to a file

pub fn not_tty(self) -> Self

If this path is for stdin/stdout they must be a pipe not a tty

pub fn atomic(self) -> Self

Make writing atomic, by writing to a temp file then doing an atomic swap

pub fn default_name(self, name: &'static str) -> Self

The default name to use for the file if the path is a directory