pub struct OsStrParser<T> { /* private fields */ }Available on crate feature
clap-parse only.Implementations
Sourceimpl<T> OsStrParser<T>
impl<T> OsStrParser<T>
Sourcepub fn atomic(self) -> Self
pub fn atomic(self) -> Self
Make writing atomic, by writing to a temp file then doing an atomic swap
Sourcepub fn default_name(self, name: &'static str) -> Self
pub fn default_name(self, name: &'static str) -> Self
The default name to use for the file if the path is a directory